.. DST documentation master file, created by
   sphinx-quickstart on Tue Dec  7 17:30:07 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DST's documentation!
===============================

.. include:: dst.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
